# -*- coding: utf-8 -*-

"""Top-level package for deeplearning2020."""

__author__ = """into-ai"""
__email__ = "introintoai@gmail.com"
__version__ = "0.3.1"

from deeplearning2020.submission import Submission as _Submission

Submission = _Submission
